Declared mutation columns, generated-column assignment rules, and table-value coercion.
Structs
- Column
Shape - What a written value needs to know of its column.
Traits
Functions
- coerce_
to_ column_ type - Coerce a write value to fit the column’s declared type.
- coerce_
to_ column_ type_ from - generated_
column_ kind - identity_
column_ sequence - The sequence
DEFAULTdraws an identity column’s value from, orNonefor a column that is not an identity column. - validate_
mutation_ columns - validate_
mutation_ targets - Validate partial targets without rejecting independent writes into the same column.