pub fn assignment_levels<E>(
steps: &[AssignmentStep<E>],
) -> Vec<AssignmentLevel<'_, E>>Expand description
Group an assignment’s indirection into fields and subscript groups, in order.
pub fn assignment_levels<E>(
steps: &[AssignmentStep<E>],
) -> Vec<AssignmentLevel<'_, E>>Group an assignment’s indirection into fields and subscript groups, in order.