pub fn has_field_step<E>(target: &AssignmentTarget<E>) -> boolExpand description
Whether an assignment writes a composite field somewhere along its indirection.
pub fn has_field_step<E>(target: &AssignmentTarget<E>) -> boolWhether an assignment writes a composite field somewhere along its indirection.