pub enum FrameExclusion {
NoOthers,
CurrentRow,
Group,
Ties,
}Expand description
The frame exclusion clause: the rows of the frame that a window function or aggregate does not see.
Variants
NoOthers
CurrentRow
Group
The current row and its peers.
Ties
The peers of the current row, but not the current row itself.
Implementations