pub struct ColumnDeclaration {
pub serial: bool,
pub serial_array: bool,
pub clauses: Vec<ColumnClause>,
}Expand description
The clauses a column definition writes, in written order, which transformColumnDefinition checks against each other.
Fields
serial: boolThe column’s type is SERIAL, SMALLSERIAL or BIGSERIAL, which adds a default after the written clauses.
serial_array: boolThe column’s type is an array of a SERIAL type.
clauses: Vec<ColumnClause>Trait Implementations
Sourceimpl Clone for ColumnDeclaration
impl Clone for ColumnDeclaration
Sourceimpl Debug for ColumnDeclaration
impl Debug for ColumnDeclaration
Sourceimpl Default for ColumnDeclaration
impl Default for ColumnDeclaration
Sourceimpl<'de> Deserialize<'de> for ColumnDeclaration
impl<'de> Deserialize<'de> for ColumnDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ColumnDeclaration
Sourceimpl PartialEq for ColumnDeclaration
impl PartialEq for ColumnDeclaration
Sourceimpl Serialize for ColumnDeclaration
impl Serialize for ColumnDeclaration
impl StructuralPartialEq for ColumnDeclaration