pub struct DeferredCreateTable {
pub name: String,
pub persistence: RelationPersistence,
pub definition_sql: String,
}Expand description
A syntactically valid CREATE TABLE IF NOT EXISTS whose definition must be analyzed only after execution has established that the target relation does not already exist.
Fields
name: Stringpersistence: RelationPersistencedefinition_sql: StringTrait Implementations
Sourceimpl Clone for DeferredCreateTable
impl Clone for DeferredCreateTable
Sourcefn clone(&self) -> DeferredCreateTable
fn clone(&self) -> DeferredCreateTable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeferredCreateTable
impl Debug for DeferredCreateTable
Sourceimpl<'de> Deserialize<'de> for DeferredCreateTable
impl<'de> Deserialize<'de> for DeferredCreateTable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeferredCreateTable
Sourceimpl PartialEq for DeferredCreateTable
impl PartialEq for DeferredCreateTable
Sourceimpl Serialize for DeferredCreateTable
impl Serialize for DeferredCreateTable
impl StructuralPartialEq for DeferredCreateTable