pub fn analyze_query_plan_schema(
routines: &dyn RoutineResolution,
plan: &QueryPlan,
params: &[SQLParam],
ctes: &BindingContext<'_>,
outer: Option<&RowSchema>,
) -> Result<RowSchema, SQLError>Expand description
Analyze every catalog and scalar reference and derive the exact output row type without executing the query.