resolve_variable_sites

Function resolve_variable_sites 

pub fn resolve_variable_sites(
    routines: &dyn RoutineResolution,
    plan: &mut UnifiedPlan,
    params: &[SQLParam],
    ctes: &BindingContext<'_>,
    names: Vec<ScalarExpr>,
) -> Result<Vec<VariableSiteResolution>, SQLError>
Find how each variable site of a PL/pgSQL statement resolves in the statement. plan is the statement with each name that the function’s variables take replaced by the positional parameter whose number is the site’s, typed by params, and names holds those names as written, in site order.