pub struct SyntaxSites {
pub routines: Vec<BoundRoutineReference>,
pub values: Vec<ValueSite>,
}Expand description
Everything binding recorded for one piece of stored syntax, in syntax order.
Fields
routines: Vec<BoundRoutineReference>Routine calls, each reported after its arguments as the syntax visitor reports calls.
values: Vec<ValueSite>Casts, unknown literals and function ordering syntax in pre-order.