Module access_methods

Module access_methods 

The access methods of pg_am: PostgreSQL 18’s own table and index methods, and the vector index methods the engine adds.

Enums

AccessMethodKind
The type of an access method (pg_am.amtype).

Functions

access_method_kind
The type of the access method name, which names one exactly, or None when no access method has that name.