pub fn access_method_kind(name: &str) -> Option<AccessMethodKind>Expand description
The type of the access method name, which names one exactly, or None when no access method has that name.
pub fn access_method_kind(name: &str) -> Option<AccessMethodKind>The type of the access method name, which names one exactly, or None when no access method has that name.