Module constraints

Module constraints 

Structs

ConstraintIdentity

Functions

constraint_identities_match
find_live_constraint_identity
Reconcile a retained constraint with a renamed row before considering a renamed relation. A removed row on a surviving relation must not bind to another partition copy.
foreign_key_identity