pub enum DependencyKind {
Normal,
Auto,
Internal,
PartitionPrimary,
PartitionSecondary,
Extension,
AutoExtension,
}Expand description
pg_depend.deptype.
Variants
Normal
n: dropping the referenced object requires CASCADE, which drops the dependent.
Auto
a: the dependent is dropped with the referenced object even without CASCADE.
Internal
i: the dependent is part of the referenced object’s implementation and can only be dropped with it.
PartitionPrimary
P: a partition’s object depends on its parent’s.
PartitionSecondary
S: a partition’s object depends on its partition.
Extension
e: the dependent is a member of an extension.
AutoExtension
x: the dependent needs an extension and is dropped with it.
Implementations