pub struct SharedDependency {
pub database: u32,
pub dependent: ObjectAddress,
pub referenced: ObjectAddress,
pub kind: SharedDependencyKind,
}Expand description
A dependency of an object on a role or tablespace, which every database shares.
Fields
database: u32dbid: the database holding the dependent object, or zero for an object that every database shares.
dependent: ObjectAddressreferenced: ObjectAddresskind: SharedDependencyKindTrait Implementations