pub fn declaration(row: &CatalogIndexRow) -> Result<CreateIndex, Error>Expand description
Restore the complete SQL declaration for validation or a physical rebuild without changing its durable catalog identity.
pub fn declaration(row: &CatalogIndexRow) -> Result<CreateIndex, Error>Restore the complete SQL declaration for validation or a physical rebuild without changing its durable catalog identity.