pub struct DroppedAttribute {
pub number: i16,
pub type_length: i64,
pub type_modifier: i64,
pub dimensions: i64,
pub by_value: bool,
pub alignment: String,
pub storage: String,
pub collation: i64,
pub identity: String,
pub is_local: bool,
pub inheritance_count: i64,
}Expand description
A dropped attribute has no live name, type dependency, default or ACL. Its physical type metadata survives even when the old type is subsequently removed.
Fields
number: i16type_length: i64type_modifier: i64dimensions: i64by_value: boolalignment: Stringstorage: Stringcollation: i64identity: Stringis_local: boolinheritance_count: i64Implementations