pub enum RelationOidKind {
Table,
View,
ForeignTable,
Sequence,
CompositeType,
}Expand description
The kinds of relation whose OIDs differ in which companion objects exist.
Variants
Table
Tables and partitioned tables: a row type and its array type.
View
Views and materialized views: a row type, its array type and the _RETURN rule.
ForeignTable
Foreign tables: a row type and its array type.
Sequence
Sequences have no row type.
CompositeType
Standalone composite types: the composite relation, its row type and the row type’s array type.