relation_creation_schema

Function relation_creation_schema 

pub fn relation_creation_schema(
    state: &dyn RelationCandidateState,
    privileges: &SchemaPrivilegeInquiry<'_>,
    current_user: &(impl RoleSubject + ?Sized),
) -> Option<String>
The schema recomputeNamespacePath makes the creation namespace of an unqualified relation: the first schema of the search path that exists and that the role may use, where pg_temp stands for the session’s temporary namespace, which a relation created there creates when it does not exist yet.