CreationRelationGuards

Trait CreationRelationGuards 

pub trait CreationRelationGuards {
    // Required methods
    fn named_type_exists(&self, identity: &RelationIdentity) -> bool;
    fn tables(&self) -> Box<dyn CreationRelationNames + '_>;
    fn views(&self) -> Box<dyn CreationRelationNames + '_>;
    fn sequences(&self) -> Box<dyn CreationRelationNames + '_>;
    fn foreign_tables(&self) -> Box<dyn CreationRelationNames + '_>;
    fn indexes(&self) -> Box<dyn CreationRelationNames + '_>;
    fn composite_types(&self) -> Box<dyn CreationRelationNames + '_>;
}

Required Methods

fn named_type_exists(&self, identity: &RelationIdentity) -> bool

fn tables(&self) -> Box<dyn CreationRelationNames + '_>

fn views(&self) -> Box<dyn CreationRelationNames + '_>

fn sequences(&self) -> Box<dyn CreationRelationNames + '_>

fn foreign_tables(&self) -> Box<dyn CreationRelationNames + '_>

fn indexes(&self) -> Box<dyn CreationRelationNames + '_>

fn composite_types(&self) -> Box<dyn CreationRelationNames + '_>

The relations of standalone composite types, which occupy the relation namespace as well as the type namespace.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors