pub enum RelationResolution {
Found(String, &'static str),
MissingRelation,
MissingSchema(String),
}Expand description
Complete outcome of resolving one relation reference through a statement namespace.
Variants
Implementations
Sourceimpl RelationResolution
impl RelationResolution
Sourcepub fn into_found(self) -> Option<(String, &'static str)>
pub fn into_found(self) -> Option<(String, &'static str)>
Collapse namespace absence only for SQL boundaries whose contract reports an undefined relation for either absence outcome.