pub struct RoleDropAuthority { /* private fields */ }Expand description
Initial CREATEROLE authority is checked once; each later target uses the current membership graph after preceding removals.
Implementations
Sourceimpl RoleDropAuthority
impl RoleDropAuthority
pub fn new( current: RoleReference, session: RoleReference, roles: &BTreeMap<String, RoleDefinition>, ) -> Result<Self, SQLError>
Sourcepub fn resolve_target(
&self,
context: &RoleValidationContext<'_>,
requested: &RoleSpecification,
if_exists: bool,
roles: &BTreeMap<String, RoleDefinition>,
) -> Result<Option<RoleBinding>, SQLError>
pub fn resolve_target( &self, context: &RoleValidationContext<'_>, requested: &RoleSpecification, if_exists: bool, roles: &BTreeMap<String, RoleDefinition>, ) -> Result<Option<RoleBinding>, SQLError>
Resolve only the next target. Execution must finish its object wait and remove its memberships before requesting another target.