Role references of the catalog: the retained registries that name roles, and the roles that session-local relations reference. DROP ROLE reports what depends on a role from the catalog’s shared dependencies.
Role references of the catalog: the retained registries that name roles, and the roles that session-local relations reference. DROP ROLE reports what depends on a role from the catalog’s shared dependencies.