Module dependencies

Module dependencies 

Added role dependencies are computed for each independently stored ACL.

Traits

AclRoleReferences

Functions

added_acl_roles
added_table_acl_roles
An existing dependency in another column or the relation ACL does not replace the dependency of this ACL. Ownership already protects the owner; PUBLIC has no role object.