pub struct BoundSchemaSecurity {
pub tuple: Option<SchemaTupleIdentity>,
pub role_owner: RoleIdentity,
pub acl: Option<Vec<BoundAclEntry<SchemaPrivileges>>>,
}Fields
tuple: Option<SchemaTupleIdentity>role_owner: RoleIdentityacl: Option<Vec<BoundAclEntry<SchemaPrivileges>>>Implementations
Sourceimpl BoundSchemaSecurity
impl BoundSchemaSecurity
pub const BUILTIN_NAMES: [&'static str; 3]
Sourcepub fn initial_catalog() -> BTreeMap<String, Self>
pub fn initial_catalog() -> BTreeMap<String, Self>
The initial namespace authority shared by memory and durable catalogs.
pub fn builtin(name: &str) -> Option<Self>
pub fn namespace_oid(&self, name: &str) -> i64
pub fn owner(role_owner: RoleIdentity) -> Self
pub fn bootstrap(name: &str) -> Self
Sourcepub fn bootstrap_with_oid(name: &str, oid: u32) -> Self
pub fn bootstrap_with_oid(name: &str, oid: u32) -> Self
A bootstrap schema whose namespace took oid, as a graph’s schema takes the OID its creation allocated.
pub fn with_public_privileges(create: bool) -> Self
pub fn bind( security: &SchemaSecurity, roles: &BTreeMap<String, RoleDefinition>, ) -> Result<Self, String>
pub fn resolve( &self, roles: &BTreeMap<String, RoleDefinition>, ) -> Result<SchemaSecurity, String>
pub fn validate( &self, roles: &BTreeMap<String, RoleDefinition>, ) -> Result<(), String>
pub fn depends_on(&self, role: RoleIdentity) -> bool
pub fn from_row(row: BoundSchemaRow) -> (String, Self)
pub fn row(&self, name: impl Into<String>) -> BoundSchemaRow