pub struct TemporaryNamespace {
pub schema: String,
pub oids: TemporaryNamespaceOids,
}Expand description
A session’s created temporary namespace as the catalog shows it.
Fields
schema: Stringpg_temp_N.
oids: TemporaryNamespaceOidsImplementations
Sourceimpl TemporaryNamespace
impl TemporaryNamespace
Sourcepub fn toast_schema(&self) -> String
pub fn toast_schema(&self) -> String
pg_toast_temp_N, named by the temporary namespace’s number.
Sourcepub fn namespace_oid(&self, name: &str) -> Option<u32>
pub fn namespace_oid(&self, name: &str) -> Option<u32>
The OID of name when it names the temporary namespace or its TOAST namespace.