pub fn apply_attribute_change(
value: Value,
ty: &ColumnType,
target: u32,
change: &AttributeChange,
catalog: &dyn CompositeTypeCatalog,
) -> Result<Value>Expand description
Apply change to every value of the composite type target in value, which has the declared type ty. Nested composite values are rewritten through their types’ attributes before the change.