pub fn fold_unknown_literal(
catalog: Option<&dyn EnumLabelCatalog>,
value: &Value,
target: &ColumnType,
) -> Result<Option<Value>>Expand description
Convert an unknown literal to an enum or enum-array type with the type’s input function, as PostgreSQL does when it coerces an untyped constant during parse analysis. Returns None for any other target.