pub fn is_enum_bearing(ty: &ColumnType) -> boolExpand description
Whether a declared type is an enum or an array whose leaf is an enum.
pub fn is_enum_bearing(ty: &ColumnType) -> boolWhether a declared type is an enum or an array whose leaf is an enum.