pub fn render_enum_labels( catalog: Option<&dyn EnumLabelCatalog>, value: &Value, ) -> Result<Value>
Replace every enum carrier inside a value by its label text, as the output functions of containers do.