pub fn read_catalog_input(
text: &str,
target: &ColumnType,
engine: &dyn EngineHook,
) -> Result<Value>Expand description
Read a catalog-dependent constant once, retaining its typed datum in stored syntax.
pub fn read_catalog_input(
text: &str,
target: &ColumnType,
engine: &dyn EngineHook,
) -> Result<Value>Read a catalog-dependent constant once, retaining its typed datum in stored syntax.