EngineValueCatalog

Struct EngineValueCatalog 

pub struct EngineValueCatalog<'a>(pub &'a dyn EngineHook);
Adapt a scalar context without requiring embedders that only provide domain or composite metadata to implement enum support.

Tuple Fields

0: &'a dyn EngineHook