pub struct UpdatePlan {Show 18 fields
pub table: String,
pub target_relation_bound: bool,
pub relations_bound: bool,
pub statement_privilege_subject: Option<String>,
pub target_privilege_subject: Option<String>,
pub target_qualifier: String,
pub include_descendants: bool,
pub assignments: Vec<AssignmentPlan>,
pub predicate: Option<ScalarExpr>,
pub ctes: Vec<CtePlan>,
pub source: Option<Box<SourcePlan>>,
pub returning: Vec<ProjectionPlan>,
pub returning_aliases: ReturningAliases,
pub subqueries: Vec<QueryPlan>,
pub view_checks: Vec<ViewCheckPlan>,
pub view_rule_relations: Vec<String>,
pub view_rule_update_plans: Vec<ViewRuleUpdatePlan>,
pub view_rule_returning: Option<ViewRuleReturningPlan>,
}Fields
table: Stringtarget_relation_bound: boolrelations_bound: boolWhether non-target relation references are stored catalog identities rather than names that must be resolved in the executing session.
statement_privilege_subject: Option<String>Effective role used for non-target privilege checks in an internally rewritten statement.
target_privilege_subject: Option<String>Effective role used only for privilege checks on an internally rewritten target relation.
target_qualifier: Stringinclude_descendants: boolassignments: Vec<AssignmentPlan>predicate: Option<ScalarExpr>ctes: Vec<CtePlan>source: Option<Box<SourcePlan>>returning: Vec<ProjectionPlan>returning_aliases: ReturningAliasessubqueries: Vec<QueryPlan>view_checks: Vec<ViewCheckPlan>view_rule_relations: Vec<String>view_rule_update_plans: Vec<ViewRuleUpdatePlan>view_rule_returning: Option<ViewRuleReturningPlan>Trait Implementations
Sourceimpl Clone for UpdatePlan
impl Clone for UpdatePlan
Sourcefn clone(&self) -> UpdatePlan
fn clone(&self) -> UpdatePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatePlan
impl Debug for UpdatePlan
Sourceimpl<'de> Deserialize<'de> for UpdatePlan
impl<'de> Deserialize<'de> for UpdatePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more