pub fn prune_command(command: &mut CommandPlan)Expand description
Drop unreferenced query children and remap local command expressions without evaluating them.
pub fn prune_command(command: &mut CommandPlan)Drop unreferenced query children and remap local command expressions without evaluating them.