bind_statement_variables

Function bind_statement_variables 

pub fn bind_statement_variables(
    statement: &Statement,
    resolver: &mut dyn VariableResolver,
    conflict: VariableConflict,
    resolve_sites: VariableSiteResolver<'_>,
) -> Result<Statement>
Bind the variables of an embedded statement, resolving each name that a variable takes against the columns and relations the statement can see as conflict directs.