pub struct PreparedAnalysisDependencies {
pub relations: BTreeSet<u32>,
pub routines: BTreeSet<[u8; 16]>,
}Expand description
Relations and selected routines used by the analyzed statement. Domain constraint dependencies introduced by optimization do not invalidate the statement’s already-read input constants.
Fields
relations: BTreeSet<u32>routines: BTreeSet<[u8; 16]>Trait Implementations
Sourceimpl Clone for PreparedAnalysisDependencies
impl Clone for PreparedAnalysisDependencies
Sourceimpl Debug for PreparedAnalysisDependencies
impl Debug for PreparedAnalysisDependencies
impl Eq for PreparedAnalysisDependencies
impl StructuralPartialEq for PreparedAnalysisDependencies