is_operator_join_table_function

Function is_operator_join_table_function 

pub fn is_operator_join_table_function(name: &str) -> bool
Whether a row-producing operator function owns an explicit relation argument. These functions are compiled specially so their first SQL argument is a relation identifier rather than a scalar value.