Command completion owned by the plan that executed, including delegated EXECUTE.
Functions
- command_
tag_ name - The tag of a command without its row count, as
CreateCommandNamenames a command in diagnostics such as the read-only transaction error. - set_
command_ completion - transaction_
completion