pub const fn is_sql_body_parameter(parameter: &FunctionParam) -> boolExpand description
Whether the body can name parameter: an input parameter. A procedure’s output parameter takes a placeholder in CALL but is not a parameter of its body.
pub const fn is_sql_body_parameter(parameter: &FunctionParam) -> boolWhether the body can name parameter: an input parameter. A procedure’s output parameter takes a placeholder in CALL but is not a parameter of its body.