pub fn routine_parameter_values(
types: &dyn RoutineTypeCatalog,
def: &CreateFunction,
) -> Vec<SQLParam>Expand description
Typed placeholders for the parameters the body names, against which analysis types references to them.
pub fn routine_parameter_values(
types: &dyn RoutineTypeCatalog,
def: &CreateFunction,
) -> Vec<SQLParam>Typed placeholders for the parameters the body names, against which analysis types references to them.