pub struct InlineRoutineExpression {
pub identity: [u8; 16],
pub expression: ScalarExpr,
}Expand description
A typed replacement, together with the routine identity whose recursive expansion the planner must suppress while simplifying the replacement.
Fields
identity: [u8; 16]expression: ScalarExprAuto Trait Implementations
impl Freeze for InlineRoutineExpression
impl RefUnwindSafe for InlineRoutineExpression
impl Send for InlineRoutineExpression
impl Sync for InlineRoutineExpression
impl Unpin for InlineRoutineExpression
impl UnsafeUnpin for InlineRoutineExpression
impl UnwindSafe for InlineRoutineExpression