Module registration

Module registration 

Routine replacement compatibility, security attributes, and ALTER definition analysis.

Traits

RoutineSupportAuthority

Functions

alter_routine_attributes
Apply the actions of ALTER FUNCTION to the routine AlterFunction found and whose ownership it checked, in its order: the actions in written order, which a procedure may not use for its function-only attributes and none may repeat; LEAKPROOF, which needs a superuser; COST; ROWS, positive and only for a set-returning routine; the SUPPORT function; and PARALLEL. The SET actions are left for the caller to apply last.
prepare_routine_replacement
validate_routine_security_attributes
validate_routine_support