Module binding

Module binding 

Bind legacy routine names once and validate retained owner and ACL incarnations.

Structs

BoundRoutineAuthority
LegacyRoutineAclEntry
Only the initial catalog converter may interpret named routine authority.

Functions

added_routine_acl_roles
bind_legacy_authority
bind_routine_grantees
routine_role_dependencies
validate_routine_authority
validate_routine_authority_identities