routine_acl_warning

Function routine_acl_warning 

pub fn routine_acl_warning(is_grant: bool, name: &str) -> SQLNotice
The warning of a GRANT or REVOKE on the routine name whose grantor holds the grant option for none of its privileges, which names the routine by its local name.