pub fn validate_drop_expression(
context: &ColumnAlterAnalysisContext<'_>,
table: &str,
name: &str,
if_exists: bool,
) -> Result<Option<SQLNotice>, SQLError>Expand description
ATExecDropExpression’s checks: the notice that skips a column that is not generated under IF EXISTS, or None to drop the expression of a stored generated column.