Module removal

Module removal 

Discover foreign keys that depend on a deleted column in catalog order.

Traits

ColumnRemovalCatalog

Functions

foreign_keys_referencing_column
Foreign keys that reference column, or that reference the key of a constraint whose supporting index includes it: dropping an included column drops that constraint.