pub enum ForeignKeyLocation {
Column(usize),
Table(usize),
}Expand description
Where a relation declares a foreign key.
Variants
Implementations
Sourceimpl ForeignKeyLocation
impl ForeignKeyLocation
pub const fn constraint(self) -> ConstraintLocation
Sourcepub fn derived<'a>(
self,
columns: &'a [ColumnDef],
constraints: &'a TableConstraintSet,
) -> Option<(&'a str, &'a [ReferencedPartitionConstraint])>
pub fn derived<'a>( self, columns: &'a [ColumnDef], constraints: &'a TableConstraintSet, ) -> Option<(&'a str, &'a [ReferencedPartitionConstraint])>
The name and derived constraints of the foreign key at this location.
Sourcepub fn derived_mut<'a>(
self,
columns: &'a mut [ColumnDef],
constraints: &'a mut TableConstraintSet,
) -> Option<&'a mut Vec<ReferencedPartitionConstraint>>
pub fn derived_mut<'a>( self, columns: &'a mut [ColumnDef], constraints: &'a mut TableConstraintSet, ) -> Option<&'a mut Vec<ReferencedPartitionConstraint>>
The derived constraints of the foreign key at this location, for an edit.