derived_constraint_alteration

Function derived_constraint_alteration 

pub fn derived_constraint_alteration(
    table: &str,
    name: &str,
    ancestor: &ConstraintAncestor,
) -> SQLError
ALTER CONSTRAINT of a constraint derived from another, which PostgreSQL refuses so that the derived constraints keep following the one they derive from.