bind_stored_schema_expression

Function bind_stored_schema_expression 

pub fn bind_stored_schema_expression(
    context: &SchemaBindingContext<'_, '_>,
    expression: &mut Expr,
    typed_expression: Expr,
) -> Result<bool, SQLError>
Bind a copy of stored schema expression syntax and carry its exact routine identities, user-defined type identities and enum constants back into the syntax. typed_expression is the syntax with its column references replaced by typed placeholders.