pub fn validate(
definition: &CreateDomain,
allow_missing: bool,
) -> ConstraintMetadataResult<()>Expand description
Unmaterialized declarations and initial legacy conversion may omit metadata. Supplied corrupt metadata is never replaced.
pub fn validate(
definition: &CreateDomain,
allow_missing: bool,
) -> ConstraintMetadataResult<()>Unmaterialized declarations and initial legacy conversion may omit metadata. Supplied corrupt metadata is never replaced.