Declared column types affected by a domain constraint change.
Enums
Functions
- column_
domain_ dependency - Classify a resolved column type using the statement’s live domain and composite definitions. Embedded domain bases can predate catalog changes and are not a substitute for those definitions.