Module keys

Module keys 

Typed index-key preparation and column names assigned at index creation.

Functions

key_names
prepare_index_definition
Bind keys and predicates and retain the public attribute names assigned before expression simplification.
prepare_index_keys
require_column_key