InheritanceCatalog

Trait InheritanceCatalog 

pub trait InheritanceCatalog {
    // Required methods
    fn resolve_parent(&self, name: &str) -> Result<String, SQLError>;
    fn declared_constraints(
        &self,
        table: &str,
    ) -> Result<TableConstraintSet, String>;
    fn check_definitions(&self, table: &str) -> Result<Vec<TableCheck>, String>;
    fn unique_index_keys(
        &self,
        table: &str,
    ) -> Result<Vec<Vec<IndexKey>>, String>;
}
Parent lookup and constraint declarations used while assembling a new row type.

Required Methods

fn resolve_parent(&self, name: &str) -> Result<String, SQLError>

fn declared_constraints( &self, table: &str, ) -> Result<TableConstraintSet, String>

fn check_definitions(&self, table: &str) -> Result<Vec<TableCheck>, String>

fn unique_index_keys(&self, table: &str) -> Result<Vec<Vec<IndexKey>>, String>

The key attributes of each unique index of table that no key constraint owns; a partition builds an index for each.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors