pub enum PartitionKeyIndex {
Adopted,
Created,
}Expand description
How a partition receives a key defined on its ancestor.
Variants
Adopted
The partition has an equivalent key, whose index becomes the partition’s index of the new key.
Created
The partition builds a new index for the key.