validate_key_definition

Function validate_key_definition 

pub fn validate_key_definition(
    relation: &KeyRelation<'_>,
    key: &TableKeyConstraint,
) -> Result<(), SQLError>
Validate a key as DefineIndex does before it builds the key’s index on relation: the index’s attributes are resolved in order, key columns before included columns; then a second primary key, the partition key, and each attribute as one an index can hold.