pub struct KeyPartition<'a> {
pub table: &'a str,
pub partition: Option<&'a PartitionSpec>,
pub keys: &'a [TableKeyConstraint],
}Expand description
A partition below the relation a key is defined on. DefineIndex visits each partition after its parent, siblings in partition bound order.
Fields
table: &'a strpartition: Option<&'a PartitionSpec>The partition’s own partition key, when it is partitioned.
keys: &'a [TableKeyConstraint]The partition’s keys before the new key reaches it.