pub struct ReferencedPartition {
pub partition: [u8; 16],
pub parent: Option<[u8; 16]>,
}Expand description
A referenced partition and the partitioned partition it belongs to, or None when it belongs to the foreign key’s referenced table.
Fields
partition: [u8; 16]parent: Option<[u8; 16]>Trait Implementations
Sourceimpl Clone for ReferencedPartition
impl Clone for ReferencedPartition
impl Copy for ReferencedPartition
Sourceimpl Debug for ReferencedPartition
impl Debug for ReferencedPartition
impl Eq for ReferencedPartition
Sourceimpl PartialEq for ReferencedPartition
impl PartialEq for ReferencedPartition
impl StructuralPartialEq for ReferencedPartition