pub fn sequence_ownership(
names: &[String],
) -> Result<SequenceOwnership, SQLError>Expand description
The column OWNED BY names, as PostgreSQL reads it once it has created the sequence: NONE, or a relation and one of its columns.
pub fn sequence_ownership(
names: &[String],
) -> Result<SequenceOwnership, SQLError>The column OWNED BY names, as PostgreSQL reads it once it has created the sequence: NONE, or a relation and one of its columns.