Module syntax

Module syntax 

Validate ALTER TABLE transaction restrictions and bind native relation-kind actions.

Functions

alter_foreign_table_from_table_syntax
Return a native foreign-table owner or name change, or None for valid trigger actions.
alter_sequence_from_table_syntax
alter_view_from_table_syntax
Return a native view rename, or None for a valid sequence of view event renames.
validate_alter_table_transaction