pub fn alter_view_from_table_syntax(
canonical: &str,
kind: &str,
stmt: &AlterTableStmt,
) -> Result<Option<AlterViewStmt>, SQLError>Expand description
Return a native view rename, or None for a valid sequence of view event renames.
pub fn alter_view_from_table_syntax(
canonical: &str,
kind: &str,
stmt: &AlterTableStmt,
) -> Result<Option<AlterViewStmt>, SQLError>Return a native view rename, or None for a valid sequence of view event renames.