create_table_as_columns

Function create_table_as_columns 

pub fn create_table_as_columns(
    query_schema: &RowSchema,
    column_names: &[String],
) -> Result<Vec<ColumnDef>, SQLError>
The columns of a table that a query defines, named by the column list and then by the query, as intorel_startup names them: more names than the query has columns are rejected.