pub fn validate_create_table_columns(
table: &CreateTable,
) -> Result<(), SQLError>Expand description
CheckAttributeNamesTypes: no column may take a system column’s name, and then no column may have a pseudo-type.
pub fn validate_create_table_columns(
table: &CreateTable,
) -> Result<(), SQLError>CheckAttributeNamesTypes: no column may take a system column’s name, and then no column may have a pseudo-type.