pub fn temporary_view_notice(name: &str) -> Result<SQLNotice, SQLError>
The notice DefineView reports for a view that its query makes temporary, naming the view as written without its schema.
DefineView