query_requires_statement_transaction

Function query_requires_statement_transaction 

pub fn query_requires_statement_transaction(
    context: &QueryEffectContext<'_>,
    query: &QueryPlan,
) -> Result<bool, SQLError>
Some read-only operations still need a statement transaction. PL/pgSQL exception blocks open subtransactions, and query FOR loops retain internal portals and their relation locks even when their queries and bodies do not write data.