Transaction commands that require an explicit SQL block.
Functions
- no_
active_ transaction_ error - no_
transaction_ block_ warning - The warning of
command, a command whose effect lasts only until the end of its transaction, outside a transaction block, asPostgreSQL’sWarnNoTransactionBlockreports it: such a command lasts only for its own statement. A command inside a function, or inside a block, has a transaction to last for and is not warned about. - no_
transaction_ in_ progress_ warning - The warning of a
COMMITorROLLBACKoutside a transaction block, whichPostgreSQL’sEndTransactionBlockandUserAbortTransactionBlockreport and otherwise ignore. - transaction_
in_ progress_ warning - The warning of a
BEGINinside a transaction block, or inside one of its subtransactions, whichPostgreSQL’sBeginTransactionBlockreports and otherwise ignores. - transaction_
requires_ explicit_ block