Module graph_commands

Module graph_commands 

SQL argument coercion and diagnostics for native and AGE graph commands.

Constants

AGE_DEPENDENT_OBJECTS_STILL_EXIST
AGE_DUPLICATE_SCHEMA
AGE_FEATURE_NOT_SUPPORTED
AGE_INVALID_PARAMETER_VALUE
AGE_UNDEFINED_SCHEMA
AGE_UNDEFINED_TABLE

Functions

age_error
eval_age_bool_with
eval_age_graph_name_with
eval_age_name_with
Evaluate a name/cstring argument of an AGE management function. null_message is the AGE error for a SQL NULL argument.
graph_create_name
graph_drop_name
require_age_arity
validate_graph_drop_cascade
Evaluate the optional cascade argument after the caller reads graph existence.