PostgreSQL-compatible grouping-set preparation after input schema binding.
Functions
- prepare_
distinct_ grouping_ sets GROUP BY DISTINCToperates on expanded grouping sets after parse analysis. At this point the input schema is known, so equivalent qualified and unqualified columns can share one identity and exact no-op casts can be removed without conflating expressions thatPostgreSQLresolves to different operator inputs.