valid_custom_name

Function valid_custom_name 

pub fn valid_custom_name(name: &str) -> bool
Whether name is two or more simple identifiers separated by dots (valid_custom_variable_name). A component starts with a letter, an underscore or a byte of a multibyte character, and continues with those, digits and $.