pub struct ParameterFlags(/* private fields */);Expand description
The GUC_* flags of a parameter that change how SQL treats it.
Implementations
Sourceimpl ParameterFlags
impl ParameterFlags
pub const NONE: Self
Sourcepub const LIST_INPUT: Self
pub const LIST_INPUT: Self
SET accepts a list of values, which it joins with , (GUC_LIST_INPUT).
Sourcepub const LIST_QUOTE: Self
pub const LIST_QUOTE: Self
SET quotes each string of the list as an identifier needs (GUC_LIST_QUOTE).
Sourcepub const NO_SHOW_ALL: Self
pub const NO_SHOW_ALL: Self
Left out of SHOW ALL and pg_settings (GUC_NO_SHOW_ALL).
Sourcepub const NO_RESET_ALL: Self
pub const NO_RESET_ALL: Self
RESET ALL leaves it alone (GUC_NO_RESET_ALL).
Sourcepub const REPORT: Self
pub const REPORT: Self
The server reports every change to the client in a ParameterStatus message (GUC_REPORT).
Sourcepub const IS_NAME: Self
pub const IS_NAME: Self
A string value is truncated to the length of an identifier (GUC_IS_NAME).
pub const fn union(self, other: Self) -> Self
pub const fn contains(self, other: Self) -> bool