Module setting

Module setting 

One parameter’s value in a session, as pg_settings and SHOW ALL report it.

Structs

ParameterSetting
A parameter’s value in a session, with the value RESET restores and where the current value came from.