pub struct ParameterSetting {
pub definition: &'static ParameterDefinition,
pub setting: String,
pub reset_setting: String,
pub source: &'static str,
}Expand description
A parameter’s value in a session, with the value RESET restores and where the current value came from.
Fields
definition: &'static ParameterDefinitionsetting: StringThe setting in base units, as pg_settings.setting reports it.
reset_setting: StringThe setting RESET restores, as pg_settings.reset_val reports it.
source: &'static strWhere the setting came from, as pg_settings.source reports it: default, client, override or session.
Implementations