Module units

Module units 

Integer parameter values and their units, read and shown as PostgreSQL’s parse_int, convert_to_base_unit and convert_int_from_base_unit do: C strtol and strtod number syntax, a unit of up to three characters, rounding to the nearest multiple of the next smaller unit, and display in the greatest unit that divides the value.

Enums

ParameterUnit
The base unit of an integer parameter (GUC_UNIT_*).