pub fn parse_setting( definition: &ParameterDefinition, raw: &str, ) -> Result<String, SQLError>
Read raw as a value of definition and return the setting it stands for, or the error SET reports for it.
raw
definition
SET