pub fn show_setting(definition: &ParameterDefinition, setting: &str) -> StringExpand description
Show setting as SHOW and current_setting report it: an integer in the greatest unit that divides it.
pub fn show_setting(definition: &ParameterDefinition, setting: &str) -> StringShow setting as SHOW and current_setting report it: an integer in the greatest unit that divides it.