pub fn partition_datum_text(
value: &Value,
ty: &ColumnType,
engine: Option<&dyn EngineHook>,
) -> Result<String, SQLError>Expand description
Render one bound datum of partition key type ty.
pub fn partition_datum_text(
value: &Value,
ty: &ColumnType,
engine: Option<&dyn EngineHook>,
) -> Result<String, SQLError>Render one bound datum of partition key type ty.