partition_tree

Function partition_tree 

pub fn partition_tree(
    context: &PartitionContext<'_>,
    root: &str,
    include_root: bool,
) -> Result<Vec<PartitionTreeNode>, SQLError>
The partitions below root, and root itself first when include_root names a partition, each before its own partitions, with siblings in partition order.