PartitionCatalog

Trait PartitionCatalog 

pub trait PartitionCatalog {
    // Required methods
    fn try_table_hierarchy(&self, table: &str) -> Result<TableHierarchy, String>;
    fn direct_hierarchy_children(
        &self,
        parent: &str,
    ) -> Result<Vec<String>, SQLError>;
    fn try_resolve_table_name(
        &self,
        name: &str,
    ) -> Result<Option<String>, String>;
    fn try_describe_table(
        &self,
        table: &str,
    ) -> Result<Option<Vec<ColumnDef>>, String>;
    fn try_table_object_id(
        &self,
        table: &str,
    ) -> Result<Option<[u8; 16]>, String>;
}
Hierarchy definitions needed to validate and route a row; no storage writes are exposed.

Required Methods

fn try_table_hierarchy(&self, table: &str) -> Result<TableHierarchy, String>

fn direct_hierarchy_children( &self, parent: &str, ) -> Result<Vec<String>, SQLError>

fn try_resolve_table_name(&self, name: &str) -> Result<Option<String>, String>

fn try_describe_table( &self, table: &str, ) -> Result<Option<Vec<ColumnDef>>, String>

fn try_table_object_id(&self, table: &str) -> Result<Option<[u8; 16]>, String>

The object identity of a table, which survives renames.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors