pub trait PartitionExpressions {
// Required methods
fn expression_text(&self, expression: &Expr) -> Result<String, SQLError>;
fn evaluate_bound(
&self,
expression: &Expr,
params: &[SQLParam],
) -> Result<Value, SQLError>;
fn evaluate_row(
&self,
expression: &Expr,
row: &ResultRow,
schema: &RowSchema,
params: &[SQLParam],
) -> Result<Value, SQLError>;
}Expand description
Evaluate declared partition keys and bounds with the caller’s expression scope.
Required Methods
Sourcefn expression_text(&self, expression: &Expr) -> Result<String, SQLError>
fn expression_text(&self, expression: &Expr) -> Result<String, SQLError>
Reconstruct a stored key using its retained type and routine identities and current catalog names.
fn evaluate_bound( &self, expression: &Expr, params: &[SQLParam], ) -> Result<Value, SQLError>
fn evaluate_row( &self, expression: &Expr, row: &ResultRow, schema: &RowSchema, params: &[SQLParam], ) -> Result<Value, SQLError>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".