Module retrieval

Module retrieval 

Retrieval argument binding and weight semantics, independent of physical search.

Structs

CalibratedVectorArguments
PriorMatchArguments

Functions

calibrated_vector_arguments
expect_evaluated_string
expect_f64_value
expect_field_name_or_string
expect_string
expect_usize
parse_multi_field_match_args
prior_match_arguments
text_match_field
Bind the field before the caller validates its catalog and evaluates the query.

Type Aliases

ArgumentEvaluator
MultiFieldMatchArgs