Module view_privileges

Module view_privileges 

Privilege checks at each view boundary before DML rewrite or trigger dispatch.

Traits

ViewPrivilegeCatalog
Authorization access to one loaded view and the current statement’s SELECT privileges.

Functions

ensure_delete
ensure_insert
ensure_merge
ensure_update
merge_privilege_expressions
next_layer_privilege_subject
The role whose privileges the layer after view name is checked with: the view’s owner, or for a security_invoker view the role name itself is checked as, rewritten_subject or else the current role.