pub fn view_query_shape(
services: ViewRewriteContext<'_>,
name: &str,
) -> Result<Option<ViewQueryShape>, SQLError>Expand description
The shape of the query of view name, or None when name names no regular view.
pub fn view_query_shape(
services: ViewRewriteContext<'_>,
name: &str,
) -> Result<Option<ViewQueryShape>, SQLError>The shape of the query of view name, or None when name names no regular view.