pub struct RoutineCoercionTarget {
pub type_name: String,
pub column_type: Option<ColumnType>,
}Expand description
One supplied argument’s concrete coercion destination.
Fields
type_name: Stringcolumn_type: Option<ColumnType>Named catalog types that are not represented by ColumnType retain their canonical name while leaving this carrier absent.