pub struct RoutineParameterDescriptor {
pub name: Option<String>,
pub type_name: String,
pub column_type: Option<ColumnType>,
pub has_default: bool,
pub default_type: Option<RoutineDefaultType>,
pub variadic: bool,
}Expand description
One declared input or output parameter participating in routine-call matching.
Fields
name: Option<String>type_name: Stringcolumn_type: Option<ColumnType>Catalog-resolved declaration, including named domains and their base type.
has_default: booldefault_type: Option<RoutineDefaultType>Type of the analyzed default, considered only for a structurally omitted input.
variadic: boolTrait Implementations
Sourceimpl Clone for RoutineParameterDescriptor
impl Clone for RoutineParameterDescriptor
Sourceimpl Debug for RoutineParameterDescriptor
impl Debug for RoutineParameterDescriptor
impl Eq for RoutineParameterDescriptor
impl StructuralPartialEq for RoutineParameterDescriptor