Engine-independent catalog source binding.
Functions
- user_
function_ output_ columns - Output column names of a user-defined routine used as a FROM source: OUT / INOUT /
RETURNS TABLEparameter names.Nonewhen the name is not a user routine or its result is a single unnamed column, which keeps the function-name default.