pub fn bind_source_plan_schema_for_execution(
routines: &dyn RoutineResolution,
source: &mut SourcePlan,
params: &[SQLParam],
ctes: &BindingContext<'_>,
outer: Option<&RowSchema>,
) -> Result<RowSchema, SQLError>Expand description
Bind every table-function source in one execution-owned source plan to its exact routine identity and return the schema derived from those same bindings.