pub fn analyze_plan_result(
routines: &dyn RoutineResolution,
aliases: &dyn OidAliasInput,
plan: &mut UnifiedPlan,
params: &[SQLParam],
scope: &dyn StatementBindingScope,
) -> Result<AnalyzedResult, SQLError>Expand description
Analyze a statement in one binding scope, retain input-function results in its executable tree and derive its result without running statement expressions.