access_method_kind

Function access_method_kind 

pub fn access_method_kind(name: &str) -> Option<AccessMethodKind>
The type of the access method name, which names one exactly, or None when no access method has that name.