pub fn can_attach_index(
parent: &IndexAttachmentShape<'_>,
child: &IndexAttachmentShape<'_>,
) -> boolExpand description
A constraint-owned parent requires a same-kind child constraint; an independent parent can attach either an independent or constraint-owned child index. Object identities, physical namespaces and display names are not index-shape properties.