described_relation_name

Function described_relation_name 

pub fn described_relation_name(
    relation: &RelationIdentity,
    resolve: impl FnOnce(&str) -> Result<RelationResolution, SQLError>,
) -> Result<String, SQLError>
The name PostgreSQL’s object descriptions give relation: its own name, quoted as an identifier needs, when the search path finds that relation by it, and its schema-qualified name otherwise.