acl_warning

Function acl_warning 

pub fn acl_warning(is_grant: bool, partial: bool, name: &str) -> SQLNotice
The warning PostgreSQL’s restrict_and_check_grant reports when the grantor holds the grant option for none of the privileges a GRANT or REVOKE of name names, or, when partial, for only some of them: SQLSTATE 01007 (warning_privilege_not_granted) for a grant and 01006 (warning_privilege_not_revoked) for a revocation.