pub fn select_grantor(
owner: RoleIdentity,
acl: Option<&[ObjectAclEntry]>,
current_user: &(impl RoleSubject + ?Sized),
roles: &BTreeMap<String, RoleDefinition>,
memberships: &BTreeMap<RoleMembershipKey, RoleMembership>,
) -> Option<RoleIdentity>Expand description
select_best_grantor: the owner when the current user inherits it, then the current user’s own grant option, then an inherited role’s grant option. None means the command grants or revokes nothing and warns.