parse_boolean_input

Function parse_boolean_input 

pub fn parse_boolean_input(text: &str) -> Option<bool>
boolin: PostgreSQL’s parse_bool over trimmed text, accepting case-insensitive prefixes of true, false, yes and no, on, at least two letters of off, and 1 and 0.