pub fn quote_ident(ident: &str) -> StringExpand description
Double-quote unless the identifier starts with a lowercase letter or an underscore, holds only lowercase letters, digits and underscores, and is not a keyword other than an unreserved one (quote_identifier).