Notices that a statement reports without failing.
Re-exports
pub use level::NoticeLevel;
Modules
- level
- The levels of notices.
Structs
- SQLNotice
- A notice that a statement reports without failing, as
PostgreSQL’sereportsends one belowERROR: its level, SQLSTATE and primary message, and the detail and hint that clients receive as fields of their own.