pub type VariableSiteResolver<'a> = &'a mut dyn FnMut(Statement, Vec<SQLParam>, Vec<ScalarExpr>) -> Result<Vec<VariableSiteResolution>, SQLError>;Expand description
Resolve how the variable sites of a statement resolve in it: the statement with each site as the positional parameter numbered after it, the sites’ values as typed parameters, and the sites’ names as written.