Module completion

Module completion 

Command completion owned by the plan that executed, including delegated EXECUTE.

Functions

command_tag_name
The tag of a command without its row count, as CreateCommandName names a command in diagnostics such as the read-only transaction error.
set_command_completion
transaction_completion