pub fn check_attribute_clauses(
clauses: &RoutineAttributeClauses,
is_procedure: bool,
) -> Result<(), SQLError>Expand description
Reject the first clause, in written order, that a procedure cannot have or that repeats an earlier clause, as compute_common_attribute and compute_function_attributes do.