pub fn validate_transforms(
catalog: &dyn RoutineTypeCatalog,
def: &CreateFunction,
clauses: &RoutineAttributeClauses,
) -> Result<(), SQLError>Expand description
The transforms of TRANSFORM FOR TYPE, which CreateFunction looks up for the routine’s language after it checks LEAKPROOF: each type must exist, and the first reports that no transform exists for its element type, since no transform exists for any type.