pub fn defer_function_body(
context: &RoutineCompilationContext<'_>,
def: &CreateFunction,
) -> Result<Option<CompiledFunctionBody>, SQLError>Expand description
The body CREATE FUNCTION compiles under check_function_bodies = off: the declaration is checked as always, a SQL-standard body, which the statement itself analyzes, is compiled, and a body given as a string is left unexamined, None, for each session to compile when it first calls the routine.