DROP and ALTER routine target binding and ownership validation.
Functions
- ensure_
routine_ drop_ owner RemoveObjects’ ownership check of a routine a DROP names: the owner of the routine’s schema may drop it, and otherwise only its owner, reported by the command’s kind and the name as written.- resolve_
sql_ function_ drop_ target - Find the routine a DROP item names;
requested_typesare its argument types resolved to catalog type names. - resolve_
sql_ function_ drop_ targets - Find the routines a DROP names, item by item as
RemoveObjectsdoes: each item’s routine is looked up and then passed toensure_owner, before the next item is looked up. - resolve_
sql_ routine_ alter_ target