Routine replacement compatibility, security attributes, and ALTER definition analysis.
Traits
Functions
- alter_
routine_ attributes - Apply the actions of
ALTER FUNCTIONto the routineAlterFunctionfound and whose ownership it checked, in its order: the actions in written order, which a procedure may not use for its function-only attributes and none may repeat; LEAKPROOF, which needs a superuser; COST; ROWS, positive and only for a set-returning routine; the SUPPORT function; and PARALLEL. The SET actions are left for the caller to apply last. - prepare_
routine_ replacement - validate_
routine_ security_ attributes - validate_
routine_ support