pub fn missing_altered_column(table: &str, column: &str) -> SQLErrorExpand description
The error for an ALTER COLUMN target that is not a column of the relation: every relation has the system columns, which cannot be altered, and any other name does not exist.