pub fn renamed_column_position<'a>(
relation: &str,
columns: impl IntoIterator<Item = &'a str>,
from: &str,
to: &str,
has_system_columns: bool,
) -> Result<usize, SQLError>Expand description
renameatt_internal: find the original live attribute before checking the destination. Views and standalone composite relations have no system attributes.