pub fn derived_constraint_alteration(
table: &str,
name: &str,
ancestor: &ConstraintAncestor,
) -> SQLErrorExpand description
ALTER CONSTRAINT of a constraint derived from another, which PostgreSQL refuses so that the derived constraints keep following the one they derive from.