Module names

Module names 

Constraint indexes occupy the same relation namespace as explicit indexes.

Traits

IndexNameCatalog
Relation-namespace visibility and existing constraint identities, without index mutation.

Functions

allocate_default_index_name
constraint_index_attributes
The attributes of a constraint’s supporting index: its key columns followed by the columns it includes.
name_constraint_indexes