pub struct ConstraintIndexNamer<'a> { /* private fields */ }Expand description
Names the indexes of a relation’s keys one at a time, each after the keys named before it, as index_create names each new index.
Implementations
Sourceimpl<'a> ConstraintIndexNamer<'a>
impl<'a> ConstraintIndexNamer<'a>
pub fn new( catalog: &'a dyn IndexNameCatalog, table: &str, ) -> Result<Self, SQLError>
Sourcepub fn occupy(&mut self, names: impl IntoIterator<Item = String>)
pub fn occupy(&mut self, names: impl IntoIterator<Item = String>)
Constraints the statement creates on the relation before its keys, such as a new table’s CHECK and NOT NULL constraints.