Module inheritance

Module inheritance 

CREATE TABLE inheritance and partition row-type preparation.

Modules

alter
ALTER inheritance and partition declaration rules over immutable column and constraint definitions.
origins
Track whether NOT NULL and CHECK declarations are local after a hierarchy edge changes.

Structs

InheritanceContext

Traits

InheritanceCatalog
Parent lookup and constraint declarations used while assembling a new row type.

Functions

merge_same_column
prepare_create_table_hierarchy