pub fn bind_create_table_partitioning(
context: &InheritanceContext<'_>,
table: &mut CreateTable,
) -> Result<(), SQLError>Expand description
The bound of a new partition and the partition key of a new partitioned table, in DefineRelation order: transformPartitionBound and check_new_partition_bound before ComputePartitionAttrs.