pub enum DeclaredForeignKey {
Column(usize),
Table(usize),
}Expand description
A foreign key of a declaration, by the catalog row it publishes.
Variants
Implementations
Sourceimpl DeclaredForeignKey
impl DeclaredForeignKey
Sourcepub fn by_catalog_identity(
columns: &[ColumnDef],
constraints: &TableConstraintSet,
identity: ConstraintCatalogIdentity,
) -> Option<Self>
pub fn by_catalog_identity( columns: &[ColumnDef], constraints: &TableConstraintSet, identity: ConstraintCatalogIdentity, ) -> Option<Self>
The foreign key of the declaration whose catalog row is identity.
Sourcepub fn by_family(
columns: &[ColumnDef],
constraints: &TableConstraintSet,
object_id: [u8; 16],
) -> Option<Self>
pub fn by_family( columns: &[ColumnDef], constraints: &TableConstraintSet, object_id: [u8; 16], ) -> Option<Self>
The foreign key of the declaration that belongs to the family object_id.
Sourcepub fn foreign_key(
self,
columns: &[ColumnDef],
constraints: &TableConstraintSet,
) -> Option<ForeignKey>
pub fn foreign_key( self, columns: &[ColumnDef], constraints: &TableConstraintSet, ) -> Option<ForeignKey>
The foreign key with its stored targets, as a table-level declaration.
pub fn validated( self, columns: &[ColumnDef], constraints: &TableConstraintSet, ) -> bool
pub fn set_validated( self, columns: &mut [ColumnDef], constraints: &mut TableConstraintSet, validated: bool, )
Sourcepub fn alter(
self,
columns: &mut [ColumnDef],
constraints: &mut TableConstraintSet,
enforceability: Option<bool>,
deferrability: Option<(bool, bool)>,
) -> bool
pub fn alter( self, columns: &mut [ColumnDef], constraints: &mut TableConstraintSet, enforceability: Option<bool>, deferrability: Option<(bool, bool)>, ) -> bool
Apply an ALTER CONSTRAINT enforceability and deferrability change. A foreign key that stops being enforced is no longer valid, and one that becomes enforced is not valid until its rows are validated; reports whether it became enforced.
pub fn set_family( self, columns: &mut [ColumnDef], constraints: &mut TableConstraintSet, object_id: [u8; 16], )