wrong_drop_kind_error

Function wrong_drop_kind_error 

pub fn wrong_drop_kind_error(
    local: &str,
    expected: &str,
    found: &str,
) -> SQLError
DropErrorMsgWrongType: a DROP names a relation of another kind, and the hint names the command that drops the kind it is.