pub fn view_becomes_temporary(
persistence: RelationPersistence,
uses_temporary_relation: bool,
) -> boolExpand description
Whether DefineView makes a view temporary because its query uses a temporary relation, which it reports with a notice before it resolves the view’s namespace.