Module transaction_blocks

Module transaction_blocks 

Transaction commands that require an explicit SQL block.

Functions

no_active_transaction_error
no_transaction_block_warning
The warning of command, a command whose effect lasts only until the end of its transaction, outside a transaction block, as PostgreSQL’s WarnNoTransactionBlock reports it: such a command lasts only for its own statement. A command inside a function, or inside a block, has a transaction to last for and is not warned about.
no_transaction_in_progress_warning
The warning of a COMMIT or ROLLBACK outside a transaction block, which PostgreSQL’s EndTransactionBlock and UserAbortTransactionBlock report and otherwise ignore.
transaction_in_progress_warning
The warning of a BEGIN inside a transaction block, or inside one of its subtransactions, which PostgreSQL’s BeginTransactionBlock reports and otherwise ignores.
transaction_requires_explicit_block