cte_definition_references

Function cte_definition_references 

pub fn cte_definition_references(
    ctes: &[CtePlan],
    index: usize,
) -> BTreeSet<String>
The WITH items of ctes that the definition of the item at index names: the items defined before it, or any item of a recursive list.