mutation_clause_schema

Function mutation_clause_schema 

pub fn mutation_clause_schema(
    target: &RowSchema,
    target_qualifier: &str,
    supplemental: Option<&RowSchema>,
) -> RowSchema
The row scope of the clauses of a data-modifying statement other than RETURNING: the target, named by its name or alias, with its system columns, and the statement’s other sources. The old and new aliases of the target belong to RETURNING alone.