SQL argument coercion and diagnostics for native and AGE graph commands.
Constants
- AGE_
DEPENDENT_ OBJECTS_ STILL_ EXIST - AGE_
DUPLICATE_ SCHEMA - AGE_
FEATURE_ NOT_ SUPPORTED - AGE_
INVALID_ PARAMETER_ VALUE - AGE_
UNDEFINED_ SCHEMA - AGE_
UNDEFINED_ TABLE
Functions
- age_
error - eval_
age_ bool_ with - eval_
age_ graph_ name_ with - eval_
age_ name_ with - Evaluate a
name/cstringargument of an AGE management function.null_messageis the AGE error for a SQL NULL argument. - graph_
create_ name - graph_
drop_ name - require_
age_ arity - validate_
graph_ drop_ cascade - Evaluate the optional cascade argument after the caller reads graph existence.