pub fn validate_grouped_expressions(
routines: &dyn RoutineResolution,
statement: &QueryBlockPlan,
schema: &RowSchema,
outer: Option<&RowSchema>,
params: &[SQLParam],
) -> Result<(), SQLError>Expand description
Validate the grouped expressions of a query whose own columns schema holds over outer, the scope of the queries that enclose it.