pub fn apply_propagated_view_lock(
plan: &mut QueryPlan,
target: &ResolvedRowLock,
)Expand description
Apply a row mark selected for a stored view to the view plan before execution. Stored view plans are not present when the SQL compiler pushes row marks into derived tables, so runtime expansion must perform the same propagation to ensure an outer NOWAIT or SKIP LOCKED policy is merged before an inner row mark can block.