The value text of SET name TO argument, ..., flattened as PostgreSQL’s flatten_set_variable_args does: only a list parameter takes several arguments, which are joined with , , and a string of a quoted list is quoted as an identifier needs.
Enums
- SetArgument
- One argument of
SET, as the grammar delivers it.
Functions
- flatten_
set_ arguments - The value text that
SET name TO argumentsassigns.