pub fn partition_bound_order(
context: &PartitionContext<'_>,
partitions: Vec<(String, PartitionBound)>,
) -> Result<Vec<String>, SQLError>Expand description
The names of partitions, which are siblings, in the order of PostgreSQL’s partition descriptor: range partitions by lower bound, list partitions by their smallest value followed by a partition that holds only NULL, hash partitions by modulus and remainder, and the default partition last.