pub fn partition_tree(
context: &PartitionContext<'_>,
root: &str,
include_root: bool,
) -> Result<Vec<PartitionTreeNode>, SQLError>Expand description
The partitions below root, and root itself first when include_root names a partition, each before its own partitions, with siblings in partition order.